JUSTVPN
=======

|PackageLicense| |Author| |PythonVersion|

一个方便连接江苏科技大学内网的Python库
--------------------------------------

对Python的request库中Session类进行了简单封装,Demo为访问知网

依赖：

-  bs4
-  requests
-  lxml

.. |PackageLicense| image:: https://img.shields.io/packagist/l/doctrine/orm.svg
.. |Author| image:: https://img.shields.io/badge/author-koswu-orange.svg
.. |PythonVersion| image:: https://img.shields.io/badge/python-%3E%3D3.6-brightgreen.svg

